California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Prior Elections
NOVEMBER 6, 2012, GENERAL
11 Measures
PROPOSITION 030 - TEMPORARY TAXES TO FUND EDUCATION. GUARANTEED LOCAL PUBLIC SAFETY FUNDING. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROPOSITION 031 - STATE BUDGET. STATE AND LOCAL GOVERNMENT. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE.
PROPOSITION 032 - PROHIBITS POLITICAL CONTRIBUTIONS BY PAYROLL DEDUCTIONS. PROHIBITIONS ON CONTRIBUTIONS TO CANDIDATES. INITIATIVE STATUTE.
PROPOSITION 033 - CHANGES LAW TO ALLOW AUTO INSURANCE COMPANIES TO SET PRICES BASED ON A DRIVER'S HISTORY OF INSURANCE COVERAGE. INITIATIVE STATUTE.
PROPOSITION 034 - DEATH PENALTY REPEAL. INITIATIVE STATUTE.
PROPOSITION 035 - HUMAN TRAFFICKING. PENALTIES. SEX OFFENDER REGISTRATION. INITIATIVE STATUTE.
PROPOSITION 036 - THREE STRIKES LAW. SENTENCING FOR REPEAT FELONY OFFENDERS. INITIATIVE STATUTE.
PROPOSITION 037 - GENETICALLY ENGINEERED FOODS. MANDATORY LABELING. INITIATIVE STATUTE.
PROPOSITION 038 - TAX FOR EARLY EDUCATION AND EARLY CHILDHOOD PROGRAMS. INITIATIVE STATUTE.
PROPOSITION 039 - TAX TREATMENT FOR MULTISTATE BUSINESSES. CLEAN ENERGY AND ENERGY EFFICIENCY FUNDING. INITIATIVE STATUTE.
PROPOSITION 040 - REDISTRICTING. STATE SENATE DISTRICTS. REFERENDUM.
JUNE 5, 2012, PRIMARY
2 Measures
PROPOSITION 028 - LIMITS ON LEGISLATORS' TERMS IN OFFICE. INITIATIVE CONSTITUTIONAL AMENDMENT.
PROPOSITION 029 - IMPOSES ADDITIONAL TAX ON CIGARETTES FOR CANCER RESEARCH. INITIATIVE STATUTE.